@@ -2,7 +2,7 @@ import '../sass/tbxforms.scss';
 
 class TbxForms {
     static selector() {
-        return 'form.tbxforms-form';
+        return 'form.tbxforms';
     }
 
     constructor(node) {
@@ -18,8 +18,8 @@ class TbxForms {
                 const container = formElement.closest('.tbxforms-form-group')
                     ? formElement.closest('.tbxforms-form-group')
                     : formElement;
-                const drivingFieldNodeList = document.querySelectorAll(
-                    `${this.form} [name="${formElement.dataset.conditionalFieldName}"]`,
+                const drivingFieldNodeList = this.form.querySelectorAll(
+                    `[name="${formElement.dataset.conditionalFieldName}"]`,
                 );
                 let conditionalValuesForElement;
 
@@ -38,6 +38,11 @@ class TbxForms {
                     // We're dealing with radios or checkboxes.
 
                     drivingFieldNodeList.forEach((option_node) => {
+                        option_node.setAttribute(
+                            'aria-controls',
+                            this.getOrCreateId(container),
+                        );
+
                         option_node.addEventListener('change', () => {
                             if (
                                 option_node.checked &&
@@ -67,6 +72,11 @@ class TbxForms {
 
                     const drivingField = drivingFieldNodeList.item(0);
 
+                    drivingField.setAttribute(
+                        'aria-controls',
+                        this.getOrCreateId(container),
+                    );
+
                     drivingField.addEventListener('change', () => {
                         if (
                             conditionalValuesForElement.includes(
@@ -101,6 +111,14 @@ class TbxForms {
         });
     }
 
+    getOrCreateId(node) {
+        if (!node.id) {
+            // If the element doesn't have an ID, generate one that's likely to be unique.
+            node.id = `tbxforms-autoid-${Math.random().toString(12)}`;
+        }
+        return node.id;
+    }
+
     clearInput(node) {
         /*
             Reset the value of a given input, or if we're given a container
